pub enum Show {
All,
Names,
Failed,
}Expand description
the different ways the command output can be displayed
Variants
All
Display the names of the executed commands and their output.
Names
Display the names of the executed commands and only the output of failed commands.
Failed
Display only the names and output of failed commands.