shell_executable

Function shell_executable 

pub fn shell_executable<IS: Into<String>>(command: IS) -> Executable
Creates an Executable that runs the given command in a shell environment so that shell features can be used.

In Unix-like environments, this uses the sh shell. In Windows, it uses cmd.exe.