Skip to main contentCrate conc
Source - Executable
- all information Conc needs to execute a command
- RunArgs
- named arguments for the
run function
- Show
- the different ways the command output can be displayed
- run
- Runs the given commands concurrently, prints their results, and returns the highest exit code.
- shell_command
- Provides a Command instance that executes the given command
in a shell environment so that shell features can be used.
- shell_executable
- Creates an Executable that runs the given command
in a shell environment so that shell features can be used.