Crate conc

Crate conc 

Structs

RunArgs
named arguments for the run function

Enums

Show
the different ways the command output can be displayed

Functions

run
Runs the given commands concurrently, prints their results, and returns the highest exit code.