pub fn shell_command(command: &str) -> CommandExpand description
Provides a Command instance that executes the given command in a shell environment so that shell features can be used.
In Unix-like environments, this uses the sh shell.
In Windows, it uses cmd.exe.